@@ -1,11 +1,12 @@
 #!/usr/bin/perl 
 use warnings;
+use strict;
 use PostfixWithActions;
 
-my $debug = shift || 0;
+my $debug = 0;
 my $pparser = PostfixWithActions->new();
 print "Write an expression: "; 
-my $x = <STDIN>;
+my $x = "@ARGV";
 
 # First, translate to postfix ...
 $pparser->Run($debug, $x);
@@ -29,18 +30,37 @@ $pparser->Run($debug, $x);
 
 # Let su reuse the grammar a third time.
 # Now we use it to generate the AST
+my $buildtree = sub { 
+  my $self = $_[0];
+  my $fullname = $self->YYName();
+  my ($name, $label) = split /:/, $fullname;
+  my $x = &Parse::Eyapp::Driver::YYBuildAST(@_);
+  bless $x, $label if defined($label);
+  $x;
+};
+
+{
+  no strict 'refs';
+
+  @{$_."::ISA"} = ('Parse::Eyapp::Node') for qw{ASSIGN  PLUS   TIMES DIV  NEG NUM VAR}; 
+}
+
 $pparser->YYSetaction(
   'EXP'           => sub { $_[1] }, # bypass 
-  'OPERAND:NUM'   => \&Parse::Eyapp::Driver::YYBuildAST,
-  'OPERAND:VAR'   => \&Parse::Eyapp::Driver::YYBuildAST,
-  'OP:ASSIGN'     => \&Parse::Eyapp::Driver::YYBuildAST,
-  'OP:PLUS'       => \&Parse::Eyapp::Driver::YYBuildAST,
-  'OP:TIMES'      => \&Parse::Eyapp::Driver::YYBuildAST,
-  'OP:DIV'        => \&Parse::Eyapp::Driver::YYBuildAST,
-  'OP:NEG'        => \&Parse::Eyapp::Driver::YYBuildAST,
+  'OPERAND:NUM'   => $buildtree,
+  'OPERAND:VAR'   => $buildtree,
+  'OP:ASSIGN'     => $buildtree,
+  'OP:PLUS'       => $buildtree,
+  'OP:TIMES'      => $buildtree,
+  'OP:DIV'        => $buildtree,
+  'OP:NEG'        => $buildtree,
 );
 
-*TERMINAL::info = sub { $_[0]{attr} };
 my $t = $pparser->Run($debug, $x);
 print $t->str."\n";
 
+package TERMINAL;
+sub info { $_[0]{attr} };
+
+package NUM;
+sub info { $_[0]{attr} };
